@@ -526,7 +526,7 @@
    ;; SRFI 256:
    2025 withdrawn "Minimal extension to SRFI 9/R7RS small record type definitions for inheritance"
    ;; SRFI 257:
-   nil draft "Simple extendable pattern matcher with backtracking"
+   2025 final "Simple extendable pattern matcher with backtracking"
    ;; SRFI 258:
    2025 final "Uninterned symbols"
    ;; SRFI 259:
@@ -534,7 +534,7 @@
    ;; SRFI 260:
    2025 final "Generated Symbols"
    ;; SRFI 261:
-   nil draft "Portable SRFI Library Reference"
+   2025 final "Portable SRFI Library Reference"
    ;; SRFI 262:
    nil draft "Extensible pattern matcher"
    ;; SRFI 263:
